# spiderwai77

spiderwai77 is a simple crawler for [https://www.wai77.com/](https://www.wai77.com/) 

## Table of Contents

- [Install](#install)
- [Usage](#usage)

## Install

```bash
$ pip install spiderwai77
```

## Usage

```python
>>> from spiderwai77 import SpiderWai77
>>> SpiderWai77('girl_name','file_path')
```

You can find girl_name from links like [https://www.wai77.com/category/周于希](https://www.wai77.com/category/周于希), in this case, "周于希" is a girl_name.

You can set file_path to the path of an existing folder.